==> owncloud-app-gallery-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/gallery/l10n/nb_NO.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galleri",
    "Pictures" : "Bilder",
    "Aborting preview. Could not find the file" : "Avbryter visning. Fant ikke filen",
    "No ownCloud installation (7 or higher) found at {remote}" : "Ingen ownCloud-installasjon (7 eller høyere) funnet på {remote}",
    "Invalid ownCloud url" : "Ugyldig ownCloud-url",
    "Gallery view" : "Gallerivisning",
    "Could not load the description" : "Klarte ikke å laste inn beskrivelsen",
    "Could not load the description: " : "Klarte ikke å laste inn beskrivelsen:",
    "Copyright" : "Opphavsrett",
    "Could not load the copyright notice: " : "Klarte ikke å laste inn notat om opphavsrett:",
    "Copyright notice" : "Notat om opphavsrett",
    "Link to copyright document" : "Lenke til dokument om opphavsrett",
    "This application may not work properly on your browser." : "Denne applikasjonen virker kanskje ikke optimalt i nettleseren din.",
    "For an improved experience, please install one of the following alternatives" : "For en forbedret opplevelse, installer ett av følgende alternativer",
    "Your browser is not supported!" : "Nettleseren din støttes ikke!",
    "please install one of the following alternatives" : "vennligst installer ett av følgende alternativer",
    "Configuration error" : "Konfigurasjonsfeil",
    "Error loading slideshow template" : "Feil ved lasting av mal for lysbildevisning",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>" : "<strong>Feil!</strong> Klarte ikke å generere forhåndsvisning av denne filen.<br>",
    "Next" : "Neste",
    "Play" : "Spill",
    "Pause" : "Pause",
    "Previous" : "Forrige",
    "Close" : "Lukk",
    "Download" : "Last ned",
    "Toggle background" : "Bytt bakgrunn",
    "Shared" : "Delt",
    "Error" : "Feil",
    "Error while sharing" : "Feil under deling",
    "Error while unsharing" : "Feil ved oppheving av deling",
    "Error while changing permissions" : "Feil ved endring av tillatelser",
    "Shared with you and the group {group} by {owner}" : "Delt med deg og gruppen {group} av {owner}",
    "Shared with you by {owner}" : "Delt med deg av {owner}",
    "Share with users or groups …" : "Del med brukere eller grupper ...",
    "Share with users, groups or remote users …" : "Del med brukere, grupper eller eksterne brukere ...",
    "Share" : "Del",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Del med personer på andre ownCloud-installasjoner med syntaksen brukernavn@example.com/owncloud",
    "Share link" : "Del lenke",
    "The public link will expire no later than {days} days after it is created" : "Den offentlige lenken vil utløpe senest {days} dager etter at den lages",
    "Link" : "Lenke",
    "Password protect" : "Passordbeskyttet",
    "Password" : "Passord",
    "Choose a password for the public link" : "Velg et passord for den offentlige lenken",
    "Allow editing" : "Tillat redigering",
    "Email link to person" : "Email lenke til person",
    "Send" : "Send",
    "Set expiration date" : "Sett utløpsdato",
    "Expiration" : "Utløpsdato",
    "Expiration date" : "Utløpsdato",
    "An error occured. Please try again" : "Det oppstod en feil. Prøv igjen",
    "Adding user..." : "Legger til bruker...",
    "group" : "gruppe",
    "remote" : "ekstern",
    "Resharing is not allowed" : "Videre deling er ikke tillatt",
    "Shared in {item} with {user}" : "Delt i {item} med {user}",
    "Unshare" : "Avslutt deling",
    "notify by email" : "Varsle på email",
    "can share" : "kan dele",
    "can edit" : "kan endre",
    "access control" : "tilgangskontroll",
    "create" : "opprette",
    "change" : "endre",
    "delete" : "slett",
    "Password protected" : "Passordbeskyttet",
    "Error unsetting expiration date" : "Feil ved nullstilling av utløpsdato",
    "Error setting expiration date" : "Kan ikke sette utløpsdato",
    "Sending ..." : "Sender...",
    "Email sent" : "E-post sendt",
    "Warning" : "Advarsel",
    "This share is password-protected" : "Denne delingen er passordbeskyttet",
    "The password is wrong. Try again." : "Passordet er feil. Prøv på nytt.",
    "Sort by date" : "Sorter på dato",
    "Sort by name" : "Sorter på navn",
    "Album information" : "Album-informasjon",
    "File list" : "Filliste",
    "Sorry, this file could not be found." : "Beklager, denne filen ble ikke funnet.",
    "Reasons might be:" : "Mulige årsaker:",
    "the wrong file ID was provided" : "feil fil-ID ble angitt",
    "the file was removed" : "filen ble fjernet",
    "the file is corrupt" : "filen er ødelagt",
    "the encryption key is missing" : "krypteringsnøkkelen mangler",
    "Here is the error message returned by the server: " : "Her er feilmeldingen som ble returnert av serveren:",
    "For more information, please contact your friendly ownCloud administrator." : "For mer informasjon, kontakt ownCloud-administratoren.",
    "Sorry, but the server could not fulfill your request." : "Beklager, men serveren kunne ikke utføre forespørselen din.",
    "Possible reasons for the problem:" : "Mulige årsaker til problemet:",
    "a conflicting app was installed" : "en uforenlig app var installert",
    "a required component is missing or was disconnected" : "en påkrevet komponent mangler eller var frakoblet",
    "the filesystem is not readable" : "filsystemet kan ikke leses",
    "Sorry, this link doesn't seem to work anymore." : "Beklager, denne lenken ser ikke ut til å virke lenger.",
    "the item was removed" : "elementet er fjernet",
    "the link has expired" : "lenken er utløpt",
    "sharing is disabled" : "deling er deaktivert",
    "For more information, please ask the person who has sent you this link." : "For mer informasjon, spør personen som har sendt deg lenken.",
    "Add to your ownCloud" : "Legg til i din ownCloud",
    "Picture view" : "Bildevisning"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-gallery-9.0.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/gallery/l10n/nb_NO.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galleri",
    "No pictures found" : "Ingen bilder funnet",
    "Upload pictures in the files app to display them here" : "Last opp bilder i Filer-appen for å vise dem her",
    "Nothing in here" : "Ingenting her",
    "No media files found in this folder" : "Ingen mediafiler funnet i denne mappen",
    "Aborting preview. Could not find the file" : "Avbryter visning. Fant ikke filen",
    "No ownCloud installation (7 or higher) found at {remote}" : "Ingen ownCloud-installasjon (7 eller høyere) funnet på {remote}",
    "Invalid ownCloud url" : "Ugyldig ownCloud-url",
    "Gallery view" : "Gallerivisning",
    "Could not load the description" : "Klarte ikke å laste inn beskrivelsen",
    "Could not load the description: " : "Klarte ikke å laste inn beskrivelsen:",
    "Copyright" : "Opphavsrett",
    "Could not load the copyright notice: " : "Klarte ikke å laste inn notat om opphavsrett:",
    "Copyright notice" : "Notat om opphavsrett",
    "Link to copyright document" : "Lenke til dokument om opphavsrett",
    "This application may not work properly on your browser." : "Denne applikasjonen virker kanskje ikke optimalt i nettleseren din.",
    "For an improved experience, please install one of the following alternatives" : "For en forbedret opplevelse, installer ett av følgende alternativer",
    "Your browser is not supported!" : "Nettleseren din støttes ikke!",
    "please install one of the following alternatives" : "vennligst installer ett av følgende alternativer",
    "Configuration error" : "Konfigurasjonsfeil",
    "Error loading slideshow template" : "Feil ved lasting av mal for lysbildevisning",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>" : "<strong>Feil!</strong> Klarte ikke å generere forhåndsvisning av denne filen.<br>",
    "Next" : "Neste",
    "Play" : "Spill",
    "Pause" : "Pause",
    "Previous" : "Forrige",
    "Close" : "Lukk",
    "Download" : "Last ned",
    "Toggle background" : "Bytt bakgrunn",
    "Shared" : "Delt",
    "Error" : "Feil",
    "Error while sharing" : "Feil under deling",
    "Error while unsharing" : "Feil ved oppheving av deling",
    "Error while changing permissions" : "Feil ved endring av tillatelser",
    "Shared with you and the group {group} by {owner}" : "Delt med deg og gruppen {group} av {owner}",
    "Shared with you by {owner}" : "Delt med deg av {owner}",
    "Share with users or groups …" : "Del med brukere eller grupper ...",
    "Share with users, groups or remote users …" : "Del med brukere, grupper eller eksterne brukere ...",
    "Share" : "Del",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Del med personer på andre ownCloud-installasjoner med syntaksen brukernavn@example.com/owncloud",
    "Share link" : "Del lenke",
    "The public link will expire no later than {days} days after it is created" : "Den offentlige lenken vil utløpe senest {days} dager etter at den lages",
    "Link" : "Lenke",
    "Password protect" : "Passordbeskyttet",
    "Password" : "Passord",
    "Choose a password for the public link" : "Velg et passord for den offentlige lenken",
    "Allow editing" : "Tillat redigering",
    "Email link to person" : "Email lenke til person",
    "Send" : "Send",
    "Set expiration date" : "Sett utløpsdato",
    "Expiration" : "Utløpsdato",
    "Expiration date" : "Utløpsdato",
    "An error occured. Please try again" : "Det oppstod en feil. Prøv igjen",
    "Adding user..." : "Legger til bruker...",
    "group" : "gruppe",
    "remote" : "ekstern",
    "Resharing is not allowed" : "Videre deling er ikke tillatt",
    "Shared in {item} with {user}" : "Delt i {item} med {user}",
    "Unshare" : "Avslutt deling",
    "notify by email" : "Varsle på email",
    "can share" : "kan dele",
    "can edit" : "kan endre",
    "access control" : "tilgangskontroll",
    "create" : "opprette",
    "change" : "endre",
    "delete" : "slett",
    "Password protected" : "Passordbeskyttet",
    "Error unsetting expiration date" : "Feil ved nullstilling av utløpsdato",
    "Error setting expiration date" : "Kan ikke sette utløpsdato",
    "Sending ..." : "Sender...",
    "Email sent" : "E-post sendt",
    "Warning" : "Advarsel",
    "This share is password-protected" : "Denne delingen er passordbeskyttet",
    "The password is wrong. Try again." : "Passordet er feil. Prøv på nytt.",
    "Sort by date" : "Sorter på dato",
    "Sort by name" : "Sorter på navn",
    "Album information" : "Album-informasjon",
    "File list" : "Filliste",
    "Sorry, this file could not be found." : "Beklager, denne filen ble ikke funnet.",
    "Reasons might be:" : "Mulige årsaker:",
    "the wrong file ID was provided" : "feil fil-ID ble angitt",
    "the file was removed" : "filen ble fjernet",
    "the file is corrupt" : "filen er ødelagt",
    "the encryption key is missing" : "krypteringsnøkkelen mangler",
    "Here is the error message returned by the server: " : "Her er feilmeldingen som ble returnert av serveren:",
    "For more information, please contact your friendly ownCloud administrator." : "For mer informasjon, kontakt ownCloud-administratoren.",
    "Sorry, but the server could not fulfill your request." : "Beklager, men serveren kunne ikke utføre forespørselen din.",
    "Possible reasons for the problem:" : "Mulige årsaker til problemet:",
    "a conflicting app was installed" : "en uforenlig app var installert",
    "a required component is missing or was disconnected" : "en påkrevet komponent mangler eller var frakoblet",
    "the filesystem is not readable" : "filsystemet kan ikke leses",
    "Sorry, this link doesn't seem to work anymore." : "Beklager, denne lenken ser ikke ut til å virke lenger.",
    "the item was removed" : "elementet er fjernet",
    "the link has expired" : "lenken er utløpt",
    "sharing is disabled" : "deling er deaktivert",
    "For more information, please ask the person who has sent you this link." : "For mer informasjon, spør personen som har sendt deg lenken.",
    "Add to your ownCloud" : "Legg til i din ownCloud",
    "Picture view" : "Bildevisning"
},
"nplurals=2; plural=(n != 1);");
